==> parry2d-f64-0.8.0.crate: parry2d-f64-0.8.0/README.md <==
<p align="center">
  <img src="https://parry.rs/img/logo_parry.svg" alt="crates.io" height="200px">
</p>
<p align="center">
    <a href="https://discord.gg/vt9DJSW">
        <img src="https://img.shields.io/discord/507548572338880513.svg?logo=discord&colorB=7289DA">
    </a>
    <a href="https://crates.io/crates/parry2d">
         <img src="https://img.shields.io/crates/v/parry2d.svg?style=flat-square" alt="crates.io">
    </a>
    <a href="https://crates.io/crates/parry3d">
         <img src="https://img.shields.io/crates/v/parry3d.svg?style=flat-square" alt="crates.io">
    </a>
</p>

-----

<p align = "center">
    <strong>
        <a href="http://docs.rs/parry2d">2D Documentation</a> | <a href="http://docs.rs/parry3d">3D Documentation</a> | <a href="http://parry.rs">User Guide</a>
    </strong>
</p>

-----

## What is Parry?

**Parry** is a set 2 and 3-dimensional geometric and collision detection libraries.
These libraries are `parry2d`, `parry3d`, `parry2d-f64`, and `parry3d-f64`. They are written with the Rust
programming language, by the [Dimforge](https://dimforge.com) organization. It is forever free
and open-source! We regularly give updates about our progress on [our blog](https://www.dimforge.com/blog).

## Resources and discussions
- [Dimforge](https://dimforge.com): See all the open-source projects we are working on! Follow our announcements
  on our [blog](https://www.dimforge.com/blog).
- [User guide](https://www.parry.rs/docs/): (WIP) Learn to use Rapier in your project by reading the official User Guide.
- [Discord](https://discord.gg/vt9DJSW): Come chat with us, get help, suggest features, on Discord!

## Acknowledgements
Parry is supported by our **platinum** sponsors:
<p>
  <a href="https://embark-studios.com">
    <img src="https://www.embark.dev/img/logo_black.png" width="301px">
  </a>
</p>

And our gold sponsors:

<p>
  <a href="https://fragcolor.com">
    <img src="https://dimforge.com/img/fragcolor_logo1_color_black.svg" width="151px">
  </a>
</p>

==> parry2d-f64-0.9.0.crate: parry2d-f64-0.9.0/README.md <==
<p align="center">
  <img src="https://parry.rs/img/logo_parry.svg" alt="crates.io" height="200px">
</p>
<p align="center">
    <a href="https://discord.gg/vt9DJSW">
        <img src="https://img.shields.io/discord/507548572338880513.svg?logo=discord&colorB=7289DA">
    </a>
    <a href="https://crates.io/crates/parry2d">
         <img src="https://img.shields.io/crates/v/parry2d.svg?style=flat-square" alt="crates.io">
    </a>
    <a href="https://crates.io/crates/parry3d">
         <img src="https://img.shields.io/crates/v/parry3d.svg?style=flat-square" alt="crates.io">
    </a>
</p>

-----

<p align = "center">
    <strong>
        <a href="http://docs.rs/parry2d">2D Documentation</a> | <a href="http://docs.rs/parry3d">3D Documentation</a> | <a href="http://parry.rs">User Guide</a>
    </strong>
</p>

-----

## What is Parry?

**Parry** is a set 2 and 3-dimensional geometric and collision detection libraries.
These libraries are `parry2d`, `parry3d`, `parry2d-f64`, and `parry3d-f64`. They are written with the Rust
programming language, by the [Dimforge](https://dimforge.com) organization. It is forever free
and open-source! We regularly give updates about our progress on [our blog](https://www.dimforge.com/blog).

## Resources and discussions
- [Dimforge](https://dimforge.com): See all the open-source projects we are working on! Follow our announcements
  on our [blog](https://www.dimforge.com/blog).
- [User guide](https://www.parry.rs/docs/): (WIP) Learn to use Rapier in your project by reading the official User Guide.
- [Discord](https://discord.gg/vt9DJSW): Come chat with us, get help, suggest features, on Discord!

## Acknowledgements
Parry is supported by our **platinum** sponsors:
<p>
  <a href="https://embark-studios.com">
    <img src="https://www.embark.dev/img/logo_black.png" width="301px">
  </a>
</p>

And our gold sponsors:

<p>
  <a href="https://fragcolor.com">
    <img src="https://dimforge.com/img/fragcolor_logo2_color_black.svg" width="300px">
  </a>
  <a href="https://resolutiongames.com/">
    <img src="https://dimforge.com/img/logo_resolution_games.png" width="300px" />
  </a>
</p>
